@@ -129,17 +129,17 @@ def parse_config(path, log):
     results = {}
     config = configparser.ConfigParser()
     config.read(path)
-    if 'update' not in config:
+    if 'update' in config:
+        items = config['update']
+    else:
         log.warning(
             'No [update] section found in %s, file ignored', path)
         items = {}
-    else:
-        items = config['update']
     for key in DEFAULTS:
-        if key not in items:
-            results[key] = DEFAULTS[key]
-        else:
+        if key in items:
             results[key] = items[key]
+        else:
+            results[key] = DEFAULTS[key]
     return results
 
 
@@ -226,7 +226,7 @@ def parse_options(conf):
         'debug': logging.DEBUG,
     }
     parser = get_parser(conf)
-    parser.version = "0.5.3"
+    parser.version = "0.6.0"
     opts = parser.parse_args()
     if opts.help == '-':
         parser.print_help()
@@ -379,9 +379,9 @@ def setup(loglevel=None):
 
 def get_plugins(log, opts):
     """
-    Handles plugin listing, plugin help  or load plugins.
+    Handles plugin listing, plugin help or load plugins.
 
-    return: (ip plugin, service plugin).
+    return: (ip plugin, service plugin) tuple.
     """
     ip_plugins = {}
     service_plugins = {}
@@ -433,7 +433,7 @@ def main():
         addr, age = ip_cache_data(opts)
         if age < service_plugin.ip_cache_ttl() and (addr == ip or not ip):
             log.info("Update inhibited, cache is fresh (%d/%d min)",
-                     age, service_plugin.ip_cache_ttl)
+                     age, service_plugin.ip_cache_ttl())
             raise _GoodbyeError()
     except _GoodbyeError as err:
         if err.exitcode != 0:
